@@ -11,7 +11,13 @@ from pathlib import Path
 from typing import Iterable
 
 import pytest
-import toml
+
+try:
+    import tomllib
+except ImportError:
+    # Unfortunately mypy cannot handle this try/expect pattern, and "type: ignore"
+    # is the simplest work-around. See: https://github.com/python/mypy/issues/1153
+    import tomli as tomllib  # type: ignore
 
 # TODO: skip if poetry is not available or add mark to test it explicitly
 
@@ -20,7 +26,7 @@ pytestmark = pytest.mark.release
 
 NAME = "pytest-httpserver"
 NAME_UNDERSCORE = NAME.replace("-", "_")
-PY_MAX_VERSION = (3, 12)
+PY_MAX_VERSION = (3, 13)
 
 
 @pytest.fixture(scope="session")
@@ -31,8 +37,8 @@ def pyproject_path() -> Path:
 @pytest.fixture(scope="session")
 def pyproject(pyproject_path: Path):
     assert pyproject_path.is_file()
-    with pyproject_path.open() as infile:
-        pyproject = toml.load(infile)
+    with pyproject_path.open("rb") as infile:
+        pyproject = tomllib.load(infile)
     return pyproject
 
 
@@ -228,6 +234,7 @@ def test_sdist_contents(build: Build, version: str):
             "test_urimatch.py",
             "test_wait.py",
             "test_with_statement.py",
+            "test_matcher.py",
         },
     }
 
